==> discord-playing-1.0.1.tgz: package/playing.js <==
/*
	Playing Highligh Module for DiscordJS
	Author: Flisher (andre@jmle.net)
	Branched from discord-streaming 1.1.1

    // Todo: Add arguments description here
*/

module.exports = function(bot, options) {
    var cron = require('node-cron');
 
    // Add check on startup
    bot.on("ready", () => {
		Playing.Check(bot, options);
	});
    
    // Add a Cron job every minutes
    var jobPlayingCheck = new cron.schedule('* * * * *', function(){
        /* Runs every minutes */
        Playing.Check(bot, options);
    });   
}

Playing = new Array()

Playing.Check = function (bot, options) {
	if (options && options.live) {
		// Single Server Config, will default to first guild found in the bot
		guild = bot.guilds.first();
		Playing.GamingLive(guild, options)
		Playing.GamingNotLive(guild, options)
	}
	else {
		// Multi-Servers Config
		for(var key in options) {
			// check that guild is loaded			
			guild = bot.guilds.get(key);
			if (guild) {
				Playing.GamingLive(guild, options[key])
				Playing.GamingNotLive(guild,  options[key])
			}
		
			else {
				console.log(`Playing.Check - Bot isn't connected to Guild "${key}"`)
			}
		}
	}
}

Playing.GamingLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Loop trough presence to find streamers (type 1)
		presences = guild.presences;
		if (presences) {
			presences.forEach(function(element, key){
				if (element.game) {
					if (typeof(element.game.type) != undefined) {
						if (element.game.type === 0) {
							if (options.games[element.game.name]) {
								// key = user id
								member = guild.members.get(key)
								// Check if the "live" Role exist
								if (guild.roles.find("name", options.live)) {
									// Check if the position of the "live" role is managable by the bot
									if (guild.me.highestRole.position >= guild.roles.find("name", options.live).position) {
										// Check if there is a Role required in the configuration
										bypass = false;
										if (typeof(options.required) === "undefined") {
											// If there is no required role, bypass
											bypass = true;
										}
										else {
											// Check if the required role exist and log an error message if missing
											if (!guild.roles.find("name", options.required)) 
											{
												console.log(`GamingLive - REQUIRED Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
											}

										}
										if (bypass || (member.roles.find("name", options.required))) {
											// Check if the member doesn't already have the live role
											if (!(member.roles.find("name", options.live))) {
												member.addRole(guild.roles.find("name", options.live)).catch(console.error);
											}
										}								
									}
									else {
										console.log(`GamingLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
									}
								}
								else {
									console.log(`GamingLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
								}



							}							
						}
					}
				}
			});
		}
	} 
	else {
		console.log(`GamingLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

Playing.GamingNotLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Check if the live Role exist
		if (guild.roles.find("name", options.live)) {
			// Check if the position of the "live" role is managable by the bot
			if (guild.me.highestRole.position >= guild.roles.find("name", options.live).position) {
				// Loop les membres du Role Live pour ret
				streamers = guild.roles.find("name", options.live).members
				streamers.forEach(function(member, key){
					stillPlaying = 0;
					presence = member.guild.presences.get(key);
					if (presence) {
						if (presence.game) {
							if (typeof(presence.game.type) != undefined)  {
								if (presence.game.type === 0) {
									if (options.games[presence.game.name]) {
										stillPlaying = 1;
									}
								}
							}
						}
						if (stillPlaying == 0)
						{
							member.removeRole(guild.roles.find("name", options.live)).catch(console.error);
						}
					}
				});
			}
			else {
				console.log(`GamingNotLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
			}
		}
		else {
			console.log(`GamingNotLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
		}
	}
	else {
		console.log(`GamingNotLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

==> discord-playing-1.2.0.tgz: package/playing.js <==
/*
	Playing Highligh Module for DiscordJS
	Author: Flisher (andre@jmle.net)
	Version 1.2

    // Todo: Add arguments description here
*/

module.exports = function(bot, options) {
    var cron = require('node-cron');
 
    // Add check on startup
    bot.on("ready", () => {
		Playing.Check(bot, options);
	});
    
    // Add a Cron job every minutes
    var jobPlayingCheck = new cron.schedule('* * * * *', function(){
        /* Runs every minutes */
        Playing.Check(bot, options);
    });   
}

Playing = new Array()

Playing.Check = function (bot, options) {
	if (options && options.live) {
		// Single Server Config, will default to first guild found in the bot
		guild = bot.guilds.first();
		Playing.GamingLive(guild, options)
		Playing.GamingNotLive(guild, options)
	}
	else {
		// Multi-Servers Config
		for(var key in options) {
			// check that guild is loaded			
			guild = bot.guilds.get(key);
			if (guild) {
				Playing.GamingLive(guild, options[key])
				Playing.GamingNotLive(guild,  options[key])
			}
		
			else {
				console.log(`Playing.Check - Bot isn't connected to Guild "${key}"`)
			}
		}
	}
}

Playing.GamingLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Loop trough presence to find streamers (type 1)
		presences = guild.presences;
		if (presences) {
			presences.forEach(function(element, key){
				if (element.game) {
					if (typeof(element.game.type) != undefined) {
						if (element.game.type === 0) {
							if (options.games[element.game.name]) {
								// key = user id
								member = guild.members.get(key)
								// Check if the "live" Role exist
								if (guild.roles.find(val => val.name === options.live)) {
										val => val.username === 'Bob'
									// Check if the position of the "live" role is managable by the bot
									if (guild.me.highestRole.position >= guild.roles.find(val => val.name === options.live).position) {
										// Check if there is a Role required in the configuration
										bypass = false;
										if (typeof(options.required) === "undefined") {
											// If there is no required role, bypass
											bypass = true;
										}
										else {
											// Check if the required role exist and log an error message if missing
											if (!guild.roles.find(val => val.name === options.required)) 
											{
												console.log(`GamingLive - REQUIRED Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
											}

										}
										if (bypass || (member.roles.find(val => val.name === options.required))) {
											// Check if the member doesn't already have the live role
											if (!(member.roles.find(val => val.name === options.live))) {
												member.addRole(guild.roles.find(val => val.name === options.live)).catch(console.error);
											}
										}								
									}
									else {
										console.log(`GamingLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
									}
								}
								else {
									console.log(`GamingLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
								}



							}							
						}
					}
				}
			});
		}
	} 
	else {
		console.log(`GamingLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

Playing.GamingNotLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Check if the live Role exist
		if (guild.roles.find(val => val.name === options.live)) {
			// Check if the position of the "live" role is managable by the bot
			if (guild.me.highestRole.position >= guild.roles.find(val => val.name ===  options.live).position) {
				// Loop les membres du Role Live pour ret
				streamers = guild.roles.find(val => val.name ===  options.live).members
				streamers.forEach(function(member, key){
					stillPlaying = 0;
					presence = member.guild.presences.get(key);
					if (presence) {
						if (presence.game) {
							if (typeof(presence.game.type) != undefined)  {
								if (presence.game.type === 0) {
									if (options.games[presence.game.name]) {
										stillPlaying = 1;
									}
								}
							}
						}
						if (stillPlaying == 0)
						{
							member.removeRole(guild.roles.find(val => val.name ===  options.live)).catch(console.error);
						}
					}
				});
			}
			else {
				console.log(`GamingNotLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
			}
		}
		else {
			console.log(`GamingNotLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
		}
	}
	else {
		console.log(`GamingNotLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}
